@@ -160,11 +160,9 @@ setMethod("releaseDate", "BSgenome", function(x) metadata(x)$release_date)
 setMethod("releaseName", "BSgenome",
     function(x)
     {
-        msg <- c("Starting with Bioconductor 3.12, BSgenome objects no ",
-                 "longer have a \"release name\". As a consequence of ",
-                 "this change calling releaseName() on a BSgenome object ",
-                 "now always returns NA and is deprecated.")
-        .Deprecated(msg=c("  ", wmsg(msg)))
+        msg <- c("starting with Bioconductor 3.15, calling releaseName() ",
+                 "on a BSgenome object is defunct")
+        .Defunct(msg=c("  ", wmsg(msg)))
         NA_character_
     }
 )
